@@ -41,7 +41,7 @@ printGeneral <- function(status,
     name.col <- c("NA", "endpoint","type","operator","threshold","event")
     df.endpoint <- data.frame(matrix(NA, nrow = D, ncol = 6,
                                      dimnames = list(NULL, name.col)
-                                     ))
+                                     ), stringsAsFactors = FALSE)
     if(hierarchical){
         df.endpoint[,1] <- paste0("      ",1:D)
         names(df.endpoint)[1] <- "      priority"
