@@ -3,9 +3,9 @@
 ## author: Brice
 ## created: maj 12 2017 (14:50) 
 ## Version: 
-## last-updated: okt 30 2018 (16:21) 
+## last-updated: nov  6 2019 (14:14) 
 ##           By: Brice Ozenne
-##     Update #: 45
+##     Update #: 54
 #----------------------------------------------------------------------
 ## 
 ### Commentary: Check whether the option neutral.as.uninf is working
@@ -20,6 +20,7 @@
 if(FALSE){
     library(testthat)
     library(BuyseTest)
+    library(data.table)
 }
 
 context("Check that the option neutral.as.uninf in BuyseTest is working correctly \n")
@@ -48,7 +49,7 @@ dt.dataNA[1,memory := NA]
 ## * neutral.as.uninf = TRUE (default)
 ## the neutral observations are analysed using the following endpoints
 test_that("continue after NA (no NA)", {
-    BT.TRUE <- BuyseTest(treat ~ cont(memory) + TTE(time, 0, status),
+    BT.TRUE <- BuyseTest(treat ~ cont(memory) + TTE(time, status, threshold = 0),
                          data = dt.data,
                          neutral.as.uninf = TRUE)
     
@@ -60,8 +61,8 @@ test_that("continue after NA (no NA)", {
 })
 
 test_that("continue after NA (NA)", {
-    BT.TRUE_NA <- BuyseTest(treat ~ Cont(memory) + TTE(time, 0, status),
-                            data = dt.dataNA, method.tte = "Peron",
+    BT.TRUE_NA <- BuyseTest(treat ~ Cont(memory) + TTE(time, status, threshold = 0),
+                            data = dt.dataNA, scoring.rule = "Peron",
                             neutral.as.uninf = TRUE)
     ## summary(BT.TRUE_NA, percentage = FALSE)
     expect_equal(as.double(BT.TRUE_NA@count.favorable),c(0,0))
@@ -74,7 +75,7 @@ test_that("continue after NA (NA)", {
 ## * neutral.as.uninf = FALSE
 ## the neutral observations are not analysed using the following endpoints
 test_that("stop after NA (no NA)", {
-    BT.FALSE <- BuyseTest(treat ~ Cont(memory) + TTE(time, 0, status),
+    BT.FALSE <- BuyseTest(treat ~ Cont(memory) + TTE(time, status, threshold = 0),
                           data = dt.data,
                           neutral.as.uninf = FALSE)
     
@@ -86,7 +87,7 @@ test_that("stop after NA (no NA)", {
 })
 
 test_that("stop after NA (NA)", {
-    BT.FALSE <- BuyseTest(treat ~ Cont(memory) + TTE(time, 0, status),
+    BT.FALSE <- BuyseTest(treat ~ Cont(memory) + TTE(time, status, threshold = 0),
                           data = dt.dataNA,
                           neutral.as.uninf = FALSE)
     
